@@ -1,13 +1,16 @@
 package WebService::HealthGraph::Response;
-$WebService::HealthGraph::Response::VERSION = '0.000001';
+$WebService::HealthGraph::Response::VERSION = '0.000002';
 use Moo;
 
 use JSON::MaybeXS qw( decode_json );
-use Types::Standard qw( Bool HashRef InstanceOf Maybe );
+use Types::Standard qw( Bool InstanceOf Maybe Ref );
+
+# records could be an ArrayRef. other than that, we should be mostly dealing
+# with a HashRef
 
 has content => (
     is      => 'ro',
-    isa     => Maybe [HashRef],
+    isa     => Maybe [Ref],
     lazy    => 1,
     builder => '_build_content',
 );
@@ -49,7 +52,20 @@ WebService::HealthGraph::Response - Generic response object for WebService::Heal
 
 =head1 VERSION
 
-version 0.000001
+version 0.000002
+
+=head2 content
+
+Returns either a C<HashRef> or an C<ArrayRef> of the content, depending on what
+the HealthGraph API returns.
+
+=head2 raw
+
+Returns the raw L<HTTP::Response> object.
+
+=head2 success
+
+Returns true if the HTTP request was fetched and parsed successfully.
 
 =head1 AUTHOR
 
@@ -66,3 +82,4 @@ the same terms as the Perl 5 programming language system itself.
 
 __END__
 # ABSTRACT: Generic response object for WebService::HealthGraph
+
